import 'package:emoji_picker_flutter/emoji_picker_flutter.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

import 'package:hokoo_flutter/view/Utils/Settings/app_images.dart';
import 'package:hokoo_flutter/view/user/screens/user_bottom_navigation_screen/user_bottom_navigation_screen.dart';
import 'package:hokoo_flutter/view/utils/settings/app_colors.dart';
import 'package:hokoo_flutter/view/utils/settings/app_icons.dart';
import 'package:hokoo_flutter/view/utils/settings/app_variables.dart';
import 'package:hokoo_flutter/view/utils/settings/models/comment_model.dart';
import 'package:hokoo_flutter/view/utils/widgets/size_configuration.dart';
import 'package:video_player/video_player.dart';

class FakeLivePage extends StatefulWidget {
  final String videoUrl;

  const FakeLivePage({
    Key? key,
    required this.videoUrl,
  }) : super(key: key);

  @override
  State<FakeLivePage> createState() => _FakeLivePageState();
}

class _FakeLivePageState extends State<FakeLivePage> {
  late VideoPlayerController _controller;

  @override
  void initState() {
    // TODO: implement initState

    _controller = VideoPlayerController.network(widget.videoUrl)
      ..initialize().then((_) {
        setState(() {
          _controller.play();
        });
      });
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return NotificationListener<OverscrollIndicatorNotification>(
      onNotification: (overscroll) {
        overscroll.disallowIndicator();
        return false;
      },
      child: WillPopScope(
        onWillPop: () async {
          demoStreamList.clear();

          selectedIndex = 0;
          Get.offAll(const UserBottomNavigationScreen());
          return false;
        },
        child: Scaffold(
          floatingActionButton: buildTextField(context),
          floatingActionButtonLocation: FloatingActionButtonLocation.centerFloat,
          body: Stack(
            children: [
              SizedBox(
                height: Get.height,
                width: Get.width,
                child: _controller.value.isInitialized
                    ? AspectRatio(
                        aspectRatio: _controller.value.aspectRatio,
                        child: VideoPlayer(_controller),
                      )
                    : const Center(child: CircularProgressIndicator()),
              ),
              SizedBox(
                height: Get.height,
                width: Get.width,
                child: Column(
                  children: [
                    Padding(
                      padding: const EdgeInsets.only(
                        top: 40,
                        right: 10,
                        left: 10,
                      ),
                      child: Row(
                        children: [
                          GestureDetector(
                            onTap: () {
                              Get.bottomSheet(
                                shape: const OutlineInputBorder(
                                    borderSide: BorderSide.none,
                                    borderRadius: BorderRadius.only(
                                        topRight: Radius.circular(20), topLeft: Radius.circular(20))),
                                backgroundColor: const Color(0xff161622),
                                Container(
                                  height: Get.height / 2.1,
                                  decoration: const BoxDecoration(
                                    borderRadius: BorderRadius.only(
                                      topLeft: Radius.circular(20),
                                      topRight: Radius.circular(20),
                                    ),
                                  ),
                                  child: Column(
                                    children: [
                                      Padding(
                                        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 15),
                                        child: Row(
                                          mainAxisAlignment: MainAxisAlignment.end,
                                          children: [
                                            GestureDetector(
                                              onTap: () => Get.back(),
                                              child: const SizedBox(
                                                height: 20,
                                                width: 20,
                                                child: Icon(
                                                  Icons.close,
                                                  color: Color(0xffDCDCDC),
                                                  size: 25,
                                                ),
                                              ),
                                            ),
                                          ],
                                        ),
                                      ),
                                      Container(
                                        alignment: Alignment.center,
                                        padding: const EdgeInsets.all(3),
                                        height: SizeConfig.blockSizeVertical * 14,
                                        width: SizeConfig.blockSizeHorizontal * 28,
                                        decoration: const BoxDecoration(
                                            shape: BoxShape.circle,
                                            gradient: LinearGradient(
                                                begin: Alignment.topLeft,
                                                end: Alignment.bottomRight,
                                                colors: [
                                                  Color(0xffE5477A),
                                                  Color(0xffE5477A),
                                                  Color(0xffE5477A),
                                                  Color(0xffE5477A),
                                                  AppColors.appBarColor,
                                                  AppColors.appBarColor,
                                                  AppColors.appBarColor,
                                                ])),
                                        child: Container(
                                          decoration: BoxDecoration(
                                              shape: BoxShape.circle,
                                              image: DecorationImage(
                                                  image: NetworkImage(
                                                      "https://3.bp.blogspot.com/-cAF9_h5aPO0/WL2taNNbv7I/AAAAAAAA05c/RmhNPqTp988LF42oHDjjOqcHKeDdtYMlwCLcB/s1600/Beautiful-Girl-Wallpapers-11.jpg"),
                                                  fit: BoxFit.cover)),
                                        ),
                                      ),
                                      const SizedBox(
                                        height: 10,
                                      ),
                                      Text(
                                        "Moni",
                                        style: TextStyle(
                                            color: Colors.white,
                                            fontWeight: FontWeight.bold,
                                            fontSize: SizeConfig.blockSizeHorizontal * 5.8),
                                      ),
                                      const SizedBox(
                                        height: 10,
                                      ),
                                      Row(
                                        mainAxisAlignment: MainAxisAlignment.center,
                                        children: [
                                          Container(
                                            margin: EdgeInsets.only(right: SizeConfig.blockSizeHorizontal * 3),
                                            padding: const EdgeInsets.all(5),
                                            height: SizeConfig.blockSizeVertical * 3.5,
                                            width: SizeConfig.blockSizeHorizontal * 15,
                                            decoration: BoxDecoration(
                                                borderRadius: BorderRadius.circular(15),
                                                color: const Color(0xff6C2D42),
                                                border: Border.all(width: 1, color: const Color(0xffD97998))),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.spaceAround,
                                              children: [
                                                Container(
                                                  alignment: Alignment.center,
                                                  width: SizeConfig.blockSizeHorizontal * 4,
                                                  decoration: const BoxDecoration(
                                                      image: DecorationImage(
                                                          image: AssetImage(AppIcons.genderIcon),
                                                          fit: BoxFit.fill)),
                                                ),
                                                Text("22",
                                                    style: TextStyle(
                                                        color: Colors.white,
                                                        fontWeight: FontWeight.bold,
                                                        fontSize: SizeConfig.blockSizeHorizontal * 3))
                                              ],
                                            ),
                                          ),
                                          Text(
                                            "India",
                                            style: TextStyle(
                                                color: Colors.white,
                                                fontWeight: FontWeight.w600,
                                                fontSize: SizeConfig.blockSizeVertical * 1.8),
                                          ),
                                        ],
                                      ),
                                      const SizedBox(
                                        height: 30,
                                      ),
                                      Padding(
                                        padding:
                                            EdgeInsets.symmetric(horizontal: SizeConfig.blockSizeHorizontal * 5),
                                        child: Row(
                                          mainAxisAlignment: MainAxisAlignment.center,
                                          children: [
                                            GestureDetector(
                                              onTap: () {},
                                              child: Container(
                                                padding: EdgeInsets.symmetric(
                                                    horizontal: SizeConfig.blockSizeHorizontal * 4),
                                                height: SizeConfig.blockSizeVertical * 6,
                                                width: SizeConfig.screenWidth * .53,
                                                decoration: BoxDecoration(
                                                    borderRadius: BorderRadius.circular(15),
                                                    border: Border.all(width: 1, color: Colors.grey),
                                                    color: const Color(0xff2A2A2A)),
                                                child: Row(
                                                  mainAxisAlignment: MainAxisAlignment.center,
                                                  children: [
                                                    Image.asset(
                                                      AppIcons.commentIcon,
                                                      color: Colors.white,
                                                      width: SizeConfig.blockSizeHorizontal * 6,
                                                    ),
                                                    const SizedBox(width: 10),
                                                    Text(
                                                      "Say Hi",
                                                      style: TextStyle(
                                                          color: Colors.white,
                                                          fontSize: SizeConfig.blockSizeHorizontal * 4.5,
                                                          fontWeight: FontWeight.w500),
                                                    )
                                                  ],
                                                ),
                                              ),
                                            ),
                                          ],
                                        ),
                                      )
                                    ],
                                  ),
                                ),
                              );
                            },
                            child: Row(
                              children: [
                                CircleAvatar(
                                  backgroundColor: AppColors.pinkColor,
                                  radius: 27,
                                  child: CircleAvatar(
                                    radius: 25,
                                    foregroundImage: NetworkImage(
                                        "https://3.bp.blogspot.com/-cAF9_h5aPO0/WL2taNNbv7I/AAAAAAAA05c/RmhNPqTp988LF42oHDjjOqcHKeDdtYMlwCLcB/s1600/Beautiful-Girl-Wallpapers-11.jpg"),
                                  ),
                                ),
                                const SizedBox(
                                  width: 8,
                                ),
                                Column(
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Text(
                                      "Moni",
                                      style: const TextStyle(
                                        color: Colors.white,
                                        fontSize: 16,
                                        fontWeight: FontWeight.w600,
                                      ),
                                    ),
                                    Row(
                                      children: [
                                        Container(
                                          height: 20,
                                          width: 20,
                                          decoration: const BoxDecoration(
                                              image: DecorationImage(
                                            image: AssetImage(AppImages.multiCoin),
                                          )),
                                        ),
                                        const SizedBox(
                                          width: 5,
                                        ),
                                        Obx(
                                          () => Text(
                                            hostCoin.value,
                                            style: const TextStyle(
                                              color: Colors.white,
                                              fontSize: 15,
                                              fontWeight: FontWeight.w600,
                                            ),
                                          ),
                                        )
                                      ],
                                    )
                                  ],
                                ),
                              ],
                            ),
                          ),
                          const Spacer(),
                          Container(
                            alignment: Alignment.center,
                            height: 35,
                            width: 60,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(10),
                              color: AppColors.pinkColor,
                            ),
                            child: const Text(
                              "LIVE",
                              style: TextStyle(
                                color: Colors.white,
                                fontWeight: FontWeight.w800,
                                fontSize: 17,
                              ),
                            ),
                          ),
                          const SizedBox(
                            width: 8,
                          ),
                          Container(
                            alignment: Alignment.center,
                            height: 35,
                            width: 60,
                            decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(10),
                              color: const Color(0xffD9D9D9).withOpacity(0.29),
                            ),
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                              children: [
                                const Icon(
                                  Icons.visibility,
                                  color: Colors.white,
                                  size: 22,
                                ),
                                Text(
                                  "12",
                                  style: const TextStyle(
                                    fontSize: 16,
                                    fontWeight: FontWeight.w500,
                                    color: Colors.white,
                                  ),
                                ),
                              ],
                            ),
                          ),
                          const SizedBox(
                            width: 8,
                          ),
                          GestureDetector(
                            onTap: () {},
                            child: const CircleAvatar(
                                radius: 18,
                                backgroundImage: AssetImage(
                                  AppImages.powerOff,
                                )),
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Column buildTextField(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.end,
      children: [
        commentSection(),
        Row(
          children: [
            Focus(
              child: Container(
                height: 45,
                width: Get.width / 1.47,
                margin: const EdgeInsets.only(left: 10, right: 10, top: 20),
                decoration: BoxDecoration(
                    border: Border.all(width: 1, color: Colors.white),
                    borderRadius: BorderRadius.circular(25),
                    color: Colors.transparent),
                child: TextFormField(
                  keyboardAppearance: Brightness.light,
                  cursorColor: Colors.white,
                  style: const TextStyle(color: Colors.white),
                  onEditingComplete: () {
                    FocusScope.of(context).unfocus();
                  },
                  textAlignVertical: TextAlignVertical.center,
                  decoration: InputDecoration(
                      contentPadding: const EdgeInsets.only(left: 20, bottom: 5),
                      border: InputBorder.none,
                      hintText: "Write Comment...",
                      hintStyle: const TextStyle(color: Colors.white, fontSize: 15),
                      prefixIcon: IconButton(
                        onPressed: () {},
                        icon: const Icon(
                          Icons.emoji_emotions,
                          color: Colors.white,
                        ),
                      ),
                      suffixIcon: GestureDetector(
                        onTap: () {},
                        child: Padding(
                          padding: const EdgeInsets.all(4),
                          child: Container(
                            alignment: Alignment.center,
                            height: 20,
                            width: 20,
                            decoration: const BoxDecoration(
                              shape: BoxShape.circle,
                              color: AppColors.pinkColor,
                            ),
                            child: const Padding(
                              padding: EdgeInsets.only(left: 3),
                              child: ImageIcon(
                                color: Colors.white,
                                size: 25,
                                AssetImage(AppImages.send),
                              ),
                            ),
                          ),
                        ),
                      )),
                ),
              ),
            ),
            // const SizedBox(width: ,),
            Padding(
                padding: const EdgeInsets.only(top: 20),
                child: AbsorbPointer(
                  child: GestureDetector(
                    onTap: () {},
                    child: Container(
                      alignment: Alignment.center,
                      height: 43,
                      width: 43,
                      decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: Colors.black.withOpacity(0.40),
                      ),
                      child: Container(
                        height: 25,
                        width: 25,
                        decoration: const BoxDecoration(
                            image: DecorationImage(
                                image: AssetImage(
                          AppImages.share,
                        ))),
                      ),
                    ),
                  ),
                )),
            const SizedBox(
              width: 8,
            ),
            Padding(
              padding: const EdgeInsets.only(top: 20),
              child: GestureDetector(
                onTap: () {},
                child: Container(
                  alignment: Alignment.center,
                  height: 43,
                  width: 43,
                  decoration: const BoxDecoration(
                      shape: BoxShape.circle,
                      gradient: LinearGradient(
                        colors: [
                          Color(0xffFFB6EC),
                          AppColors.lightPinkColor,
                        ],
                        begin: Alignment.topLeft,
                        end: Alignment.bottomRight,
                      )),
                  child: Container(
                    height: 35,
                    width: 35,
                    foregroundDecoration: const BoxDecoration(
                        image: DecorationImage(
                            image: AssetImage(
                      AppImages.starGif,
                    ))),
                    decoration: const BoxDecoration(
                        image: DecorationImage(
                            image: AssetImage(
                      AppImages.giftGif,
                    ))),
                  ),
                ),
              ),
            ),
          ],
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8),
          child: Offstage(
            child: SizedBox(
              height: 270,
              child: EmojiPicker(
                config: const Config(
                  columns: 7,
                  emojiSizeMax: 34,
                  verticalSpacing: 0,
                  horizontalSpacing: 0,
                  gridPadding: EdgeInsets.zero,
                  initCategory: Category.RECENT,
                  bgColor: Color(0xFFF2F2F2),
                  indicatorColor: Colors.blue,
                  iconColor: Colors.grey,
                  iconColorSelected: Colors.blue,
                  backspaceColor: Colors.blue,
                  skinToneDialogBgColor: Colors.white,
                  skinToneIndicatorColor: Colors.grey,
                  enableSkinTones: true,

                  // showRecentsTab: true,
                  recentsLimit: 28,
                  replaceEmojiOnLimitExceed: false,
                  noRecents: Text(
                    'No Recent',
                    style: TextStyle(fontSize: 20, color: Colors.black26),
                    textAlign: TextAlign.center,
                  ),
                  loadingIndicator: SizedBox.shrink(),
                  tabIndicatorAnimDuration: kTabScrollDuration,
                  categoryIcons: CategoryIcons(),
                  buttonMode: ButtonMode.MATERIAL,
                  checkPlatformCompatibility: true,
                ),
              ),
            ),
          ),
        ),

        // (showSizeBox)
        //     ? const SizedBox(height: 280)
        //     : const SizedBox(),
      ],
    );
  }

  Stack commentSection() {
    return Stack(
      alignment: Alignment.bottomRight,
      children: [
        Container(
          margin: const EdgeInsets.only(left: 8),
          height: 220,
          child: ShaderMask(
            shaderCallback: (bounds) {
              return const LinearGradient(
                begin: Alignment.topCenter,
                end: Alignment.bottomCenter,
                colors: [Colors.purple, Colors.transparent, Colors.transparent, Colors.purple],
                stops: [0.0, 0.1, 0.9, 1.0], // 10% purple, 80% transparent, 10% purple
              ).createShader(bounds);
            },
            blendMode: BlendMode.dstOut,
            child: ListView.builder(
              shrinkWrap: true,
              reverse: false,
              itemCount: demoStreamList.length,
              itemBuilder: (BuildContext context, int index) {
                if (demoStreamList.isEmpty) {
                  return null;
                }
                return Padding(
                  padding: const EdgeInsets.only(bottom: 5, right: 80),
                  child: GestureDetector(
                    onTap: () {
                      if (FocusScope.of(context).hasFocus) {
                        FocusScope.of(context).unfocus();
                      }
                    },
                    child: Row(
                      mainAxisSize: MainAxisSize.max,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        Container(
                          decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(30),
                            color: Colors.black.withOpacity(0.10),
                          ),
                          child: Row(
                            children: <Widget>[
                              Padding(
                                padding: const EdgeInsets.only(left: 10),
                                child: Container(
                                  alignment: Alignment.center,
                                  height: 30,
                                  width: 30,
                                  decoration: const BoxDecoration(
                                      shape: BoxShape.circle,
                                      gradient: LinearGradient(
                                        colors: [
                                          AppColors.pinkColor,
                                          AppColors.pinkColor,
                                          Colors.transparent,
                                        ],
                                        begin: Alignment.topLeft,
                                        end: Alignment.bottomRight,
                                      )),
                                  child: Container(
                                    width: 28,
                                    height: 28,
                                    decoration: BoxDecoration(
                                      shape: BoxShape.circle,
                                      image: DecorationImage(
                                          image: NetworkImage(demoStreamList[index].image), fit: BoxFit.cover),
                                    ),
                                  ),
                                ),
                              ),
                              Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: <Widget>[
                                  Padding(
                                    padding: const EdgeInsets.only(
                                      left: 10,
                                      right: 40,
                                      top: 5,
                                    ),
                                    child: Text(
                                      demoStreamList[index].user,
                                      style: const TextStyle(
                                          color: AppColors.pinkColor, fontSize: 11, fontWeight: FontWeight.bold),
                                    ),
                                  ),
                                  ConstrainedBox(
                                    constraints: BoxConstraints(
                                      maxWidth: Get.width / 1.5,
                                    ),
                                    child: Padding(
                                      padding: const EdgeInsets.only(
                                        left: 10,
                                        right: 50,
                                        bottom: 3,
                                      ),
                                      child: Text(
                                        softWrap: false,
                                        demoStreamList[index].message,
                                        style: const TextStyle(
                                            color: Colors.white, fontSize: 13, overflow: TextOverflow.ellipsis),
                                        maxLines: 100,
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                  ),
                                ],
                              )
                            ],
                          ),
                        ),
                        const Spacer(),
                      ],
                    ),
                  ),
                );
              },
            ),
          ),
        ),
      ],
    );
  }
}
